PairwiseContractionOptions

Struct PairwiseContractionOptions 

pub struct PairwiseContractionOptions {
    pub lhs_conj: bool,
    pub rhs_conj: bool,
}
Options for pairwise tensor contraction.

The conjugation flags are semantically equivalent to contracting lhs.conj() or rhs.conj(), but allow implementations to pass conjugation to the backend without materializing a conjugated tensor.

Examples

use num_complex::Complex64;
use tensor4all_core::{
    contract_pair, contract_pair_with_operand_options, DynIndex,
    PairwiseContractionOptions, IdxTensor,
};

let i = DynIndex::new_dyn(2);
let lhs = IdxTensor::from_dense(
    vec![i.clone()],
    vec![Complex64::new(1.0, 2.0), Complex64::new(3.0, -1.0)],
).unwrap();
let rhs = IdxTensor::from_dense(
    vec![i],
    vec![Complex64::new(2.0, 0.5), Complex64::new(-1.0, 4.0)],
).unwrap();

let options = PairwiseContractionOptions::new().with_lhs_conj(true);
let flagged = contract_pair_with_operand_options(&lhs, &rhs, options).unwrap();
let materialized = contract_pair(&lhs.conj(), &rhs).unwrap();

assert!((flagged.sum().unwrap() - materialized.sum().unwrap()).abs() < 1e-12);

Fields

lhs_conj: bool

Whether to conjugate the left operand before contraction.

rhs_conj: bool

Whether to conjugate the right operand before contraction.

Implementations

Source

impl PairwiseContractionOptions

pub fn new() -> Self

Create pairwise contraction options with no operand conjugation.

Examples
use tensor4all_core::PairwiseContractionOptions;

let options = PairwiseContractionOptions::new();
assert!(!options.lhs_conj);
assert!(!options.rhs_conj);
pub fn with_lhs_conj(self, lhs_conj: bool) -> Self

Set whether the left operand is conjugated during contraction.

Examples
use tensor4all_core::PairwiseContractionOptions;

let options = PairwiseContractionOptions::new().with_lhs_conj(true);
assert!(options.lhs_conj);
assert!(!options.rhs_conj);
pub fn with_rhs_conj(self, rhs_conj: bool) -> Self

Set whether the right operand is conjugated during contraction.

Examples
use tensor4all_core::PairwiseContractionOptions;

let options = PairwiseContractionOptions::new().with_rhs_conj(true);
assert!(!options.lhs_conj);
assert!(options.rhs_conj);