TensorHermitianEigendecomposition

Struct TensorHermitianEigendecomposition 

pub struct TensorHermitianEigendecomposition {
    pub eigenvalues: Vec<f64>,
    pub eigenvectors: TensorDynLen,
    pub eigenvector_index: DynIndex,
}
Hermitian eigendecomposition of a rank-2 TensorDynLen.

Eigenvectors are returned as a rank-2 tensor whose first index is the input matrix row index and whose second index labels eigenvector columns. The eigenvalues are detached primal values intended for nonsmooth selection logic such as truncation cutoffs.

Examples

use tensor4all_core::{DynIndex, TensorDynLen};

let row = DynIndex::new_dyn(2);
let col = DynIndex::new_dyn(2);
let matrix = TensorDynLen::from_dense(
    vec![row.clone(), col],
    vec![1.0_f64, 0.0, 0.0, 2.0],
).unwrap();

let decomp = matrix.hermitian_eigendecomposition(1.0e-12).unwrap();

assert_eq!(decomp.eigenvalues, vec![1.0, 2.0]);
assert_eq!(
    decomp.eigenvectors.indices(),
    &[row, decomp.eigenvector_index.clone()]
);

Fields

eigenvalues: Vec<f64>

Real eigenvalues in backend Hermitian eigensolver order.

eigenvectors: TensorDynLen

Eigenvector matrix with one eigenvector in each column.

eigenvector_index: DynIndex

Index labeling the eigenvector columns.