Enum StorageKind
pub enum StorageKind {
Dense,
Diagonal,
Structured,
}Expand description
Classifies the compact layout used by Storage.
Use this to distinguish dense logical payloads from diagonal/copy payloads and general structured payloads without exposing the internal storage enum.
Examples
use tensor4all_tensorbackend::{Storage, StorageKind};
let dense = Storage::from_dense_col_major(vec![1.0_f64, 2.0], &[2]).unwrap();
assert_eq!(dense.storage_kind(), StorageKind::Dense);
let diag = Storage::from_diag_col_major(vec![1.0_f64, 2.0], 2).unwrap();
assert_eq!(diag.storage_kind(), StorageKind::Diagonal);Variants
Dense
Logical dense payload layout.
Diagonal
Diagonal or copy-tensor payload layout.
Structured
General structured payload layout with repeated axis classes.