ConjState

Enum ConjState 

pub enum ConjState {
    Undirected,
    Ket,
    Bra,
}
Conjugate state (direction) of an index.

This enum represents whether an index has a direction (bra/ket) or is directionless. The direction is used to determine contractability between indices.

QSpace Compatibility

In QSpace (extern/qspace-v4-pub), index direction is encoded via trailing * in itags:

  • Ket = ingoing index (QSpace: itag without trailing *)
  • Bra = outgoing index (QSpace: itag with trailing *)

ITensors.jl Compatibility

ITensors.jl uses directionless indices by default (convenient for general tensor operations). The Undirected variant provides this behavior.

Examples

use tensor4all_core::{DynIndex, IndexLike, ConjState};

let i = DynIndex::new_dyn(4);
// Default DynIndex is undirected
assert_eq!(i.conj_state(), ConjState::Undirected);

Variants



Undirected

Directionless index (ITensors.jl-like default).

Undirected indices can contract with other undirected indices only when their full index identity matches and their dimensions match.



Ket

Ket (ingoing) index.

In QSpace terminology, this corresponds to an index without a trailing * in its itag. Ket indices can only contract with Bra indices (and vice versa).



Bra

Bra (outgoing) index.

In QSpace terminology, this corresponds to an index with a trailing * in its itag. Bra indices can only contract with Ket indices (and vice versa).