pub enum LinearizationOrder {
ColumnMajor,
RowMajor,
}Expand description
Linearization order used when fusing or unfusing multiple logical indices into one physical index.
This matters for exact reshape-style operations such as replacing one fused index with several unfused indices.
Examples
use tensor4all_core::LinearizationOrder;
assert_eq!(LinearizationOrder::ColumnMajor.as_str(), "column-major");
assert_eq!(LinearizationOrder::RowMajor.as_str(), "row-major");Variants
Implementations