AnyScalar

Struct AnyScalar 

pub struct AnyScalar { /* private fields */ }
Dynamic scalar compatibility wrapper for tensor4all-core.

This owns a rank-0 TensorDynLen so that scalar values can participate in the same eager autodiff graph as tensors while preserving the existing dynamic scalar API shape.

Implementations

Source

impl AnyScalar

pub fn from_value<T: TensorElement>(value: T) -> Self

pub fn from_real(x: f64) -> Self

pub fn from_complex(re: f64, im: f64) -> Self

pub fn new_real(x: f64) -> Self

pub fn new_complex(re: f64, im: f64) -> Self

pub fn primal(&self) -> Self

pub fn enable_grad(self) -> Self

pub fn tracks_grad(&self) -> bool

pub fn grad(&self) -> Result<Option<Self>>

pub fn clear_grad(&self) -> Result<()>

pub fn backward(&self) -> Result<()>

pub fn detach(&self) -> Self

pub fn real(&self) -> f64

pub fn imag(&self) -> f64

pub fn abs(&self) -> f64

pub fn is_complex(&self) -> bool

pub fn is_real(&self) -> bool

pub fn is_zero(&self) -> bool

pub fn as_f64(&self) -> Option<f64>

pub fn as_c64(&self) -> Option<Complex64>

pub fn conj(&self) -> Self

pub fn real_part(&self) -> Self

pub fn imag_part(&self) -> Self

pub fn compose_complex(real: Self, imag: Self) -> Result<Self>

pub fn sqrt(&self) -> Self

pub fn powf(&self, exponent: f64) -> Self

pub fn powi(&self, exponent: i32) -> Self