build_diag_union

Function build_diag_union 

pub fn build_diag_union(tensors: &[&TensorDynLen]) -> AxisUnionFind
Build a union-find structure from a collection of tensors.

For each Diag tensor component, all its indices are unified (they share the same diagonal dimension). This creates hyperedges when multiple Diag tensors share indices.