pub struct PairwiseContractionOptions {
pub lhs_conj: bool,
pub rhs_conj: bool,
}Expand description
Options for pairwise tensor contraction.
The conjugation flags are semantically equivalent to contracting
lhs.conj() or rhs.conj(), but allow implementations to pass conjugation
to the backend without materializing a conjugated tensor.
Examples
use num_complex::Complex64;
use tensor4all_core::{
contract_pair, contract_pair_with_operand_options, DynIndex,
PairwiseContractionOptions, TensorDynLen,
};
let i = DynIndex::new_dyn(2);
let lhs = TensorDynLen::from_dense(
vec![i.clone()],
vec![Complex64::new(1.0, 2.0), Complex64::new(3.0, -1.0)],
).unwrap();
let rhs = TensorDynLen::from_dense(
vec![i],
vec![Complex64::new(2.0, 0.5), Complex64::new(-1.0, 4.0)],
).unwrap();
let options = PairwiseContractionOptions::new().with_lhs_conj(true);
let flagged = contract_pair_with_operand_options(&lhs, &rhs, options).unwrap();
let materialized = contract_pair(&lhs.conj(), &rhs).unwrap();
assert!((flagged.sum().unwrap() - materialized.sum().unwrap()).abs() < 1e-12);Fields
lhs_conj: boolWhether to conjugate the left operand before contraction.
rhs_conj: boolWhether to conjugate the right operand before contraction.
Implementations
Sourceimpl PairwiseContractionOptions
impl PairwiseContractionOptions
Sourcepub fn new() -> Self
pub fn new() -> Self
Create pairwise contraction options with no operand conjugation.
Examples
use tensor4all_core::PairwiseContractionOptions;
let options = PairwiseContractionOptions::new();
assert!(!options.lhs_conj);
assert!(!options.rhs_conj);Sourcepub fn with_lhs_conj(self, lhs_conj: bool) -> Self
pub fn with_lhs_conj(self, lhs_conj: bool) -> Self
Set whether the left operand is conjugated during contraction.
Examples
use tensor4all_core::PairwiseContractionOptions;
let options = PairwiseContractionOptions::new().with_lhs_conj(true);
assert!(options.lhs_conj);
assert!(!options.rhs_conj);Sourcepub fn with_rhs_conj(self, rhs_conj: bool) -> Self
pub fn with_rhs_conj(self, rhs_conj: bool) -> Self
Set whether the right operand is conjugated during contraction.
Examples
use tensor4all_core::PairwiseContractionOptions;
let options = PairwiseContractionOptions::new().with_rhs_conj(true);
assert!(!options.lhs_conj);
assert!(options.rhs_conj);Trait Implementations
Sourceimpl Clone for PairwiseContractionOptions
impl Clone for PairwiseContractionOptions
Sourcefn clone(&self) -> PairwiseContractionOptions
fn clone(&self) -> PairwiseContractionOptions
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PairwiseContractionOptions
impl Debug for PairwiseContractionOptions
Sourceimpl Default for PairwiseContractionOptions
impl Default for PairwiseContractionOptions
Sourcefn default() -> PairwiseContractionOptions
fn default() -> PairwiseContractionOptions
Returns the “default value” for a type. Read more
impl Copy for PairwiseContractionOptions
impl Eq for PairwiseContractionOptions
impl StructuralPartialEq for PairwiseContractionOptions