pub enum AllowedPairs<'a> {
All,
Specified(&'a [(usize, usize)]),
}Expand description
Specifies which tensor pairs are allowed to contract.
This enum controls which tensor pairs can have their indices contracted in multi-tensor contraction operations. This is useful for tensor networks where the graph structure determines which tensors are connected.
Example
use tensor4all_core::{AllowedPairs, DynIndex, TensorDynLen, TensorLike};
let i = DynIndex::new_dyn(2);
let j = DynIndex::new_dyn(2);
let k = DynIndex::new_dyn(2);
let a = TensorDynLen::from_dense(
vec![i.clone(), j.clone()],
vec![1.0, 0.0, 0.0, 1.0],
)?;
let b = TensorDynLen::from_dense(
vec![j.clone(), k.clone()],
vec![1.0, 2.0, 3.0, 4.0],
)?;
let c = TensorDynLen::from_dense(vec![k.clone()], vec![1.0, 10.0])?;
let tensor_refs: Vec<&TensorDynLen> = vec![&a, &b, &c];
let all = <TensorDynLen as TensorLike>::contract(&tensor_refs, AllowedPairs::All)?;
let edges = vec![(0, 1), (1, 2)];
let specified =
<TensorDynLen as TensorLike>::contract(&tensor_refs, AllowedPairs::Specified(&edges))?;
assert_eq!(all.dims(), vec![2]);
assert!(all.sub(&specified)?.maxabs() < 1e-12);Variants
All
All tensor pairs are allowed to contract.
Indices with matching IDs across any two tensors will be contracted.
This is the default behavior, equivalent to ITensor’s * operator.
Specified(&'a [(usize, usize)])
Only specified tensor pairs are allowed to contract.
Each pair is (tensor_idx_a, tensor_idx_b) into the input tensor slice.
Indices are only contracted if they belong to an allowed pair.
This is useful for tensor networks where the graph structure determines which tensors are connected (e.g., TreeTN edges).